<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';
import {
    MinusCircleOutlined,
} from "@ant-design/icons-vue";

const formTable = ref(null);
const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const extendField = ref([]);
const initFormData = {}
let formData = ref(initFormData);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    open.value = false;
    post(isSave.value ? '/api/mat/save' : '/api/mat/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(isSave.value ? formatMessage('page.add.success', '新增成功') : formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
        nextTick(() => {
            formTable.value.resetFields()
        })
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const UserQueryList = ref(null);
UserQuery();
function UserQuery() {
    postForm('/api/user/query', {}).then(resp => {
        let result = resp.data;
        UserQueryList.value = result.data;
    })
}
const TagQueryTree = ref(null);
TagQuery();
function TagQuery() {
    post('/api/tag/tree', {}).then(resp => {
        let result = resp.data;
        TagQueryTree.value = result.data;
    })
}

//扩展字段
getColumns()
async function getColumns() {
    let fieldResp = await post('/api/matField/list', {
        fieldType: 0
    })
    let fieldResult = fieldResp.data;
    if (fieldResult.code == 200) {
        let data = fieldResult.data;
        extendField.value = data;
    } else if (result.code === 401) {
        message.error(result.msg);
        logout()
    } else {
        message.error(result.msg);
    }
}


defineExpose({
    open,
    formData,
    initFormData,
    isSave,
})

</script>

<script>
export default {
    name: '商品档案-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" ref="formTable" name="formTable" :label-col="{ span: 8 }"
                :wrapper-col="{ span: 16 }" style="display: flex;justify-content: space-between;flex-wrap: wrap;"
                autocomplete="off" @finish="onFinish" @finishFailed="onFinishFailed">
                <!-- <a-form-item :label="formatMessage('db.man_mat.uuid', '编号')" name="uuid" style="width: 250px;">
                    <a-input v-model:value="formData.uuid" />
                </a-form-item> -->
                <!-- <a-form-item :label="formatMessage('db.man_mat.create_time', '添加时间')" name="createTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.createTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.create_by', '添加人员')" name="createBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.createBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="UserQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.update_time', '修改时间')" name="updateTime"
                    style="width: 250px;">
                    <a-date-picker v-model:value="formData.updateTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.update_by', '修改人员')" name="updateBy"
                    style="width: 250px;">
                    <a-select v-model:value="formData.updateBy" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="UserQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item> -->
                <!-- <a-form-item :label="formatMessage('db.man_mat.tag_id', '所属归类')" name="tagId" style="width: 250px;">
                    <a-select v-model:value="formData.tagId" :placeholder="formatMessage('common.select', '请选择')"
                        style="width: 100%" show-search :options="TagQueryList" optionFilterProp="label"
                        optionLabelProp="label">
                    </a-select>
                </a-form-item> -->
                <a-form-item :label="formatMessage('db.man_mat.tag_id', '所属归类')" name="tagId" style="width: 250px;"
                    :rules="[{ required: true, message: '上级菜单不能为空!' }]">
                    <a-tree-select v-model:value="formData.tagId" show-search style="width: 100%"
                        :dropdown-style="{ maxHeight: '400px', overflow: 'auto' }"
                        :placeholder="formatMessage('page.input', '请输入')" allow-clea tree-data-simple-mode
                        :tree-data="TagQueryTree" tree-node-filter-prop="name" :field-names="{
                            children: 'children',
                            label: 'name',
                            value: 'id',
                        }">
                        <template #title="{ value: id, name }">
                            {{ name }}
                        </template>
                    </a-tree-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.matnr', '商品编号')" name="matnr" style="width: 250px;"
                    :rules="[{ required: true }]">
                    <a-input v-model:value="formData.matnr" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.maktx', '商品名称')" name="maktx" style="width: 250px;">
                    <a-input v-model:value="formData.maktx" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.name', '别名')" name="name" style="width: 250px;">
                    <a-input v-model:value="formData.name" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.specs', '规格')" name="specs" style="width: 250px;">
                    <a-input v-model:value="formData.specs" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.model', '型号')" name="model" style="width: 250px;">
                    <a-input v-model:value="formData.model" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.color', '颜色')" name="color" style="width: 250px;">
                    <a-input v-model:value="formData.color" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.brand', '品牌')" name="brand" style="width: 250px;">
                    <a-input v-model:value="formData.brand" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.unit', '单位')" name="unit" style="width: 250px;">
                    <a-input v-model:value="formData.unit" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.price', '单价')" name="price" style="width: 250px;">
                    <a-input v-model:value="formData.price" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.sku', 'sku')" name="sku" style="width: 250px;">
                    <a-input v-model:value="formData.sku" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.units', '单位量')" name="units" style="width: 250px;">
                    <a-input v-model:value="formData.units" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.barcode', '条码')" name="barcode" style="width: 250px;">
                    <a-input v-model:value="formData.barcode" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.origin', '产地')" name="origin" style="width: 250px;">
                    <a-input v-model:value="formData.origin" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.manu', '厂家')" name="manu" style="width: 250px;">
                    <a-input v-model:value="formData.manu" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.manu_date', '生产日期')" name="manuDate"
                    style="width: 250px;">
                    <a-input v-model:value="formData.manuDate" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.item_num', '品项数')" name="itemNum" style="width: 250px;">
                    <a-input v-model:value="formData.itemNum" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.weight', '重量')" name="weight" style="width: 250px;">
                    <a-input v-model:value="formData.weight" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.length', '长度')" name="length" style="width: 250px;">
                    <a-input v-model:value="formData.length" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.volume', '体积')" name="volume" style="width: 250px;">
                    <a-input v-model:value="formData.volume" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.three_code', '三方编码')" name="threeCode"
                    style="width: 250px;">
                    <a-input v-model:value="formData.threeCode" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.supp', '供应商')" name="supp" style="width: 250px;">
                    <a-input v-model:value="formData.supp" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.supp_code', '供应商编码')" name="suppCode"
                    style="width: 250px;">
                    <a-input v-model:value="formData.suppCode" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.dead_time', '保质期')" name="deadTime"
                    style="width: 250px;">
                    <a-input v-model:value="formData.deadTime" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.safeStockLimit', '安全库存上限')" name="safeStockLimit"
                    style="width: 250px;">
                    <a-input v-model:value="formData.safeStockLimit" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.safeStockMinimum', '安全库存下限')" name="safeStockMinimum"
                    style="width: 250px;">
                    <a-input v-model:value="formData.safeStockMinimum" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.validity', '有效期')" name="validity"
                    style="width: 250px;">
                    <a-input v-model:value="formData.validity" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.flag', '标识')" name="flag" style="width: 250px;">
                    <a-input v-model:value="formData.flag" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.sort', '排序')" name="sort" style="width: 250px;">
                    <a-input v-model:value="formData.sort" />
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.status', '状态')" name="status" style="width: 250px;">
                    <a-select v-model:value="formData.status" :options="[
                        { label: '正常', value: 1 },
                        { label: '禁用', value: 0 },
                    ]">
                    </a-select>
                </a-form-item>
                <a-form-item :label="formatMessage('db.man_mat.memo', '备注')" name="memo" style="width: 250px;">
                    <a-input v-model:value="formData.memo" />
                </a-form-item>

                <a-form-item v-for="(item, index) in extendField" :key="index"
                    :label="formatMessage(item.language, item.describe)" :name="item.name" style="width: 250px;">
                    <a-input v-model:value="formData[item.name]" />
                </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
